#[repr(u8)]pub enum AssetVersion {
V0 = 0,
V1 = 1,
}Expand description
The version of the Taproot Asset.
Variants
V0 = 0
V0 is the default asset version. This version will include the witness vector in the leaf for a tap commitment.
V1 = 1
V1 is the asset version that leaves out the witness vector from the MS-SMT leaf encoding.