pub struct AssetGroup {
pub raw_group_key: Vec<u8>,
pub tweaked_group_key: Vec<u8>,
pub asset_witness: Vec<u8>,
pub tapscript_root: Option<Hash>,
}Expand description
Information related to the key group of an asset (if it exists).
Fields
raw_group_key: Vec<u8>The raw group key which is a normal public key.
tweaked_group_key: Vec<u8>The tweaked group key, which is derived based on the genesis point and also asset type.
asset_witness: Vec<u8>A witness that authorizes a specific asset to be part of the asset group specified by the above key.
tapscript_root: Option<Hash>The root hash of a tapscript tree, which enables future issuance authorized with a script witness.