pub struct PrevInputAsset {
pub anchor_point: OutPoint,
pub asset_id: AssetID,
pub script_key: Vec<u8>,
pub amount: u64,
}Expand description
Represents a previous input asset.
Fields
anchor_point: OutPointThe previous input’s anchor point (txid:vout).
asset_id: AssetIDThe asset ID of the asset that was spent as an input.
script_key: Vec<u8>The script key of the asset that was spent as an input.
amount: u64The amount of the asset that was spent as an input.