Module commitment

Module commitment 

Structs

AssetProof
Proof used along with an asset leaf to arrive at the root of the AssetCommitment MS-SMT. This corresponds to commitment.AssetProof in Go.
Proof
Represents a full commitment proof for a particular Asset. It proves that an asset does or does not exist within a Taproot Asset commitment. This corresponds to commitment.Proof in Go.
TaprootAssetProof
Proof used along with an asset commitment leaf to arrive at the root of the TapCommitment MS-SMT. This corresponds to commitment.TaprootAssetProof in Go.
TapscriptPreimage
Wraps a pre-image byte slice with a type byte that self identifies what type of pre-image it is. This corresponds to commitment.TapscriptPreimage in Go.

Enums

TapCommitmentVersion
Denotes the structure of the Taproot Asset commitment MS-SMT and the procedure for building a TapLeaf from a Taproot Asset commitment. This corresponds to commitment.TapCommitmentVersion in Go.
TapscriptPreimageType
Type of tapscript sibling preimage. This corresponds to commitment.TapscriptPreimageType in Go.