#[repr(u8)]pub enum TapCommitmentVersion {
V0 = 0,
V1 = 1,
V2 = 2,
}Expand description
Denotes the structure of the Taproot Asset commitment MS-SMT and the procedure
for building a TapLeaf from a Taproot Asset commitment.
This corresponds to commitment.TapCommitmentVersion in Go.
Variants
V0 = 0
Initial Taproot Asset Commitment version. Uses legacy TapLeaf format, ONLY commits to V0 assets.
V1 = 1
Used by Taproot Asset Commitments that commit to V0 or V1 assets. Uses legacy TapLeaf format.
V2 = 2
Used by Taproot Asset Commitments that commit to V0 or V1 assets. Uses V1 TapLeaf format.