pub struct AssetProof {
pub proof: MssmtProof,
pub version: AssetVersion,
pub tap_key: [u8; 32],
pub unknown_odd_types: BTreeMap<u64, Vec<u8>>,
}Expand description
Proof used along with an asset leaf to arrive at the root of the AssetCommitment MS-SMT.
This corresponds to commitment.AssetProof in Go.
Fields
proof: MssmtProofThe underlying MS-SMT proof.
version: AssetVersionMax version of the assets committed.
tap_key: [u8; 32]Common identifier for all assets found within the AssetCommitment. Can be an asset.ID or an asset.GroupKey hash.
unknown_odd_types: BTreeMap<u64, Vec<u8>>Map of unknown odd types encountered during decoding.
Implementations
Sourceimpl AssetProof
impl AssetProof
pub fn decode_tlv<R: Read>(r: R) -> Result<Self, Error>