pub struct Proof {
pub asset_proof: Option<AssetProof>,
pub taproot_asset_proof: TaprootAssetProof,
pub unknown_odd_types: BTreeMap<u64, Vec<u8>>,
}Expand description
Represents a full commitment proof for a particular Asset. It proves
that an asset does or does not exist within a Taproot Asset commitment.
This corresponds to commitment.Proof in Go.
Fields
asset_proof: Option<AssetProof>Proof used along with the asset to arrive at the root of the AssetCommitment MS-SMT. NOTE: This proof must be None if the asset commitment for this particular asset is not found within the Taproot Asset commitment.
taproot_asset_proof: TaprootAssetProofProof used along with the asset commitment to arrive at the root of the TapCommitment MS-SMT.
unknown_odd_types: BTreeMap<u64, Vec<u8>>Map of unknown odd types encountered during decoding.
Implementations