Module proof

Module proof 

Structs

CommitmentProof
Represents a full commitment proof for an asset. It can either prove inclusion or exclusion of an asset within a Taproot Asset commitment. This corresponds to proof.CommitmentProof in Go.
File
HashedProof
HashedProof is a struct that contains an encoded proof and its chained checksum.
MetaReveal
Meta reveal data included in proof files.
Proof
TaprootProof
TaprootProof represents a proof that reveals the partial contents to a tapscript tree within a taproot output. This corresponds to proof.TaprootProof in Go.
TapscriptProof
TapscriptProof represents a proof of a Taproot output not including a Taproot Asset commitment. This corresponds to proof.TapscriptProof in Go.
TxMerkleNode
A hash of the Merkle tree branch or root for transactions.
TxMerkleProof
A Merkle proof that a transaction is included in a block. This corresponds to proof.TxMerkleProof in Go.

Enums

MetaType
Meta data type for genesis reveals.

Type Aliases

RawProofFile
Represents a raw proof file, typically a byte vector. This was at the top of the original proof.rs file.