pub struct File {
pub version: u32,
pub proofs: Vec<HashedProof>,
}Fields
version: u32Version is the version of the proof file.
proofs: Vec<HashedProof>Proofs are the proofs contained within the proof file starting from the genesis proof. Each proof includes its chained hash.
Implementations
Sourceimpl File
impl File
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>
Decodes a File from a byte slice.
Sourcepub fn num_proofs(&self) -> usize
pub fn num_proofs(&self) -> usize
Returns the number of proofs contained in this file.
Sourcepub fn proof_at(&self, index: usize) -> Result<Proof, Error>
pub fn proof_at(&self, index: usize) -> Result<Proof, Error>
Returns the proof at the given index.
Sourcepub fn last_proof(&self) -> Result<Proof, Error>
pub fn last_proof(&self) -> Result<Proof, Error>
Returns the last proof in the chain of proofs.