pub struct TapscriptProof {
pub tap_preimage1: Option<TapscriptPreimage>,
pub tap_preimage2: Option<TapscriptPreimage>,
pub bip86: bool,
pub unknown_odd_types: BTreeMap<u64, Vec<u8>>,
}Expand description
TapscriptProof represents a proof of a Taproot output not including a
Taproot Asset commitment.
This corresponds to proof.TapscriptProof in Go.
Fields
tap_preimage1: Option<TapscriptPreimage>TapPreimage1 is the preimage for a TapNode at depth 0 or 1.
tap_preimage2: Option<TapscriptPreimage>TapPreimage2, if specified, is the pair preimage for TapPreimage1 at depth 1.
bip86: boolBip86 indicates this is a normal BIP-0086 wallet output.
unknown_odd_types: BTreeMap<u64, Vec<u8>>UnknownOddTypes is a map of unknown odd types encountered during decoding.