RawProofFile

Type Alias RawProofFile 

pub type RawProofFile = Vec<u8>;
Represents a raw proof file, typically a byte vector. This was at the top of the original proof.rs file.

Aliased Type

pub struct RawProofFile { /* private fields */ }