Represents a full commitment proof for a particular Asset. It proves
that an asset does or does not exist within a Taproot Asset commitment.
This corresponds to commitment.Proof in Go.
Proof used along with an asset commitment leaf to arrive at the root of the TapCommitment MS-SMT.
This corresponds to commitment.TaprootAssetProof in Go.
Wraps a pre-image byte slice with a type byte that self identifies what type of pre-image it is.
This corresponds to commitment.TapscriptPreimage in Go.
Denotes the structure of the Taproot Asset commitment MS-SMT and the procedure
for building a TapLeaf from a Taproot Asset commitment.
This corresponds to commitment.TapCommitmentVersion in Go.