pub struct CommitmentProof {
pub proof: Proof,
pub tap_sibling_preimage: Option<TapscriptPreimage>,
pub stxo_proofs: BTreeMap<SerializedKey, Proof>,
pub unknown_odd_types: BTreeMap<u64, Vec<u8>>,
}Expand description
Represents a full commitment proof for an asset. It can either prove inclusion or exclusion of
an asset within a Taproot Asset commitment.
This corresponds to proof.CommitmentProof in Go.
Fields
proof: ProofThe underlying Merkle proof structure from the commitment module.
This was commitment.Proof in Go.
tap_sibling_preimage: Option<TapscriptPreimage>TapSiblingPreimage is an optional preimage of a tap node used to hash together with the Taproot Asset commitment leaf node to arrive at the tapscript root of the expected output.
stxo_proofs: BTreeMap<SerializedKey, Proof>STXOProofs are proofs keyed by serialized script key for v1 assets.
unknown_odd_types: BTreeMap<u64, Vec<u8>>UnknownOddTypes is a map of unknown odd types that were encountered during decoding. This map is used to preserve unknown types that we don’t know of yet, so we can still encode them back when serializing. This enables forward compatibility with future versions of the protocol as it allows new odd (optional) types to be added without breaking old clients that don’t yet fully understand them.